@@ -24,12 +24,40 @@ Created on Apr 21, 2011
 @author: tmetsch
 """
 
-from Tkconstants import W, E, N, S
 from Tkinter import Tk, IntVar, StringVar
 import Tkinter
 import json
 
 
+def _contains_dict(items):
+    """
+    Checks if a set of items contains a dictionary.
+
+    items -- The set of items to test.
+    """
+    result = False
+    for item in items.keys():
+        if isinstance(items[item], dict):
+            result = True
+            break
+    return result
+
+
+def _contains_list(items):
+    """
+    Checks if a set of items contains a list.
+
+    items -- The set of items to test.
+    """
+    result = False
+    for item in items.keys():
+        if isinstance(items[item], list) and item is not item.lower():
+            # the .lower check ensures that I can have attribute lists
+            result = True
+            break
+    return result
+
+
 class TkJson(Tk):
     """
     Simple class which wraps Tk and uses some JSON to contruct a GUI.
@@ -62,15 +90,15 @@ class TkJson(Tk):
         for name in items.keys():
             current = items[name]
             if isinstance(current,
-                          dict) and not self._contains_list(
-                              current) and not self._contains_dict(current):
+                          dict) and not _contains_list(
+                              current) and not _contains_dict(current):
                 self._create_widget(name, parent, current)
 
-            elif isinstance(current, dict) and self._contains_list(current):
+            elif isinstance(current, dict) and _contains_list(current):
                 widget = self._create_widget(name, parent, current)
 
                 self.create_widgets(widget, current)
-            elif isinstance(current, dict) and self._contains_dict(current):
+            elif isinstance(current, dict) and _contains_dict(current):
                 widget = self._create_widget(name, parent, current)
 
                 self.create_widgets(widget, current)
@@ -78,35 +106,6 @@ class TkJson(Tk):
                 for item in current:
                     self.create_widgets(parent, {name: item})
 
-    # pylint: disable-msg=W0142,R0201
-
-    def _contains_dict(self, items):
-        """
-        Checks if a set of items contains a dictionary.
-
-        items -- The set of items to test.
-        """
-        result = False
-        for item in items.keys():
-            if isinstance(items[item], dict):
-                result = True
-                break
-        return result
-
-    def _contains_list(self, items):
-        """
-        Checks if a set of items contains a list.
-
-        items -- The set of items to test.
-        """
-        result = False
-        for item in items.keys():
-            if isinstance(items[item], list) and item is not item.lower():
-                # the .lower check ensures that I can have attribute lists
-                result = True
-                break
-        return result
-
     def _create_widget(self, name, parent, desc):
         """
         Tries to resolve the widget from Tk and create it.
@@ -135,7 +134,7 @@ class TkJson(Tk):
                     column=position[1],
                     columnspan=weight[0],
                     rowspan=weight[1],
-                    sticky=N + E + W + S,
+                    sticky=padding[2],
                     padx=padding[0],
                     pady=padding[1])
 
@@ -172,19 +171,21 @@ class TkJson(Tk):
         padx = 2
         pady = 2
 
+        sticky = 'news'
+
         if 'row' in dictionary:
             row = dictionary['row']
             dictionary.pop('row')
         if 'column' in dictionary:
             column = dictionary['column']
             dictionary.pop('column')
-            
+
         if 'columnspan' in dictionary:
             colspan = dictionary['columnspan']
             dictionary.pop('columnspan')
         if 'rowspan' in dictionary:
             rowspan = dictionary['rowspan']
-            dictionary.pop('rowspan')            
+            dictionary.pop('rowspan')
         if 'rowweight' in dictionary:
             rowweight = dictionary['rowweight']
             dictionary.pop('rowweight')
@@ -202,7 +203,10 @@ class TkJson(Tk):
         if 'pady' in dictionary:
             pady = dictionary['pady']
             dictionary.pop('pady')
-            
+        if 'sticky' in dictionary:
+            sticky = dictionary['sticky']
+            dictionary.pop('sticky')
+
         for key in dictionary.keys():
             if not isinstance(dictionary[key],
                               dict) and not isinstance(dictionary[key], list):
@@ -211,7 +215,7 @@ class TkJson(Tk):
                 # so we have an attribute list...
                 options[str(key)] = dictionary[key]
 
-        return [row, column], [colspan, rowspan, rowweight, colweight], [padx, pady], options
+        return [row, column], [colspan, rowspan, rowweight, colweight], [padx, pady, sticky], options
 
     ##
     # Rest is public use :-)
@@ -248,7 +252,6 @@ class TkJson(Tk):
         return var
 
     def entry(self, name, key=None, cmd=None, focus=False):
-
         """
         Returns the text of a TK widget.
 
@@ -299,7 +302,7 @@ class TkJson(Tk):
         """
         widget = self.get(widget_name)
         scrollbar = self.get(scrollbar_name)
-        
+
         widget.config(xscrollcommand=scrollbar.set)
         scrollbar.config(command=widget.xview)
 
@@ -312,7 +315,7 @@ class TkJson(Tk):
         """
         widget = self.get(widget_name)
         scrollbar = self.get(scrollbar_name)
-        
+
         widget.config(yscrollcommand=scrollbar.set)
         scrollbar.config(command=widget.yview)
 
